pub struct ToolAnnotations {
pub read_only_hint: bool,
pub destructive_hint: bool,
pub idempotent_hint: bool,
pub needs_approval_hint: bool,
pub supports_streaming_hint: bool,
}Expand description
Hints that describe behavioural properties of a tool.
These flags are advisory — they influence UI presentation and permission
policies but do not enforce behaviour at runtime. For example, a
permission policy may automatically require approval for tools that
set destructive_hint to true.
Fields
read_only_hint: boolThe tool only reads data and has no side-effects.
destructive_hint: boolThe tool may perform destructive operations (e.g. file deletion).
idempotent_hint: boolRepeated calls with the same input produce the same effect.
needs_approval_hint: boolThe tool should prompt for user approval before execution.
supports_streaming_hint: boolThe tool can stream partial results during execution.
Implementations
Sourceimpl ToolAnnotations
impl ToolAnnotations
Sourcepub fn destructive() -> Self
pub fn destructive() -> Self
Marks the tool as destructive.
Sourcepub fn needs_approval() -> Self
pub fn needs_approval() -> Self
Marks the tool as requiring approval.
pub fn with_read_only(self, read_only_hint: bool) -> Self
pub fn with_destructive(self, destructive_hint: bool) -> Self
pub fn with_idempotent(self, idempotent_hint: bool) -> Self
pub fn with_needs_approval(self, needs_approval_hint: bool) -> Self
pub fn with_supports_streaming(self, supports_streaming_hint: bool) -> Self